@@ -6,9 +6,9 @@ from os import path
 class Configuration(object):
     def __init__(self):
         self.plugin_dir = str(XDG_CONFIG_HOME) + "/streamdeck-daemon/actions"
-        config_path = str(XDG_CONFIG_HOME) + "/streamdeck-daemon/streamdeck.yaml"
-        if path.exists(config_path):
-            with open(config_path) as config_file:
+        self.config_path = str(XDG_CONFIG_HOME) + "/streamdeck-daemon/streamdeck.yaml"
+        if path.exists(self.config_path):
+            with open(self.config_path) as config_file:
                 self.config = yaml.load(config_file, Loader=yaml.FullLoader)
         else:
             with open("streamdeck.yaml") as config_file:
